@@ -20,6 +20,8 @@ from .style import (
 
 from .ansi import *
 from .markup import *
+from .stylesheet import *
+from .stylesheet import _globals
 
 
 ANSI_REGEX = re.compile("\x1b\\[.*?[ABCDEFGHJKfnsumlh]")
@@ -34,4 +36,3 @@ def filter_ansi(style: Mapping[str, Any]) -> dict[str, Ansi]:
     """
     return {k: v for k, v in style.items() if isinstance(v, Ansi)}
 
-
