@@ -89,21 +89,36 @@ class _Ground(IntEnum):
 class Color(Ansi, metaclass = ABCMeta):
     """
     Abstract Base Class for terminal dependent
-    colors
+    colors.
     """
     _termtype: Terminal
     
     def __init__(self, **data: Any):
-        self._ansi = []
+        """
+        .. attention::
+           
+           Directly initializing this class is
+           prohibited. Use one of the available
+           class methods such as
+           :meth:`from_name`, :meth:`from_rgb` or
+           :meth:`from_hex`.
+        
+        Parameters
+        ----------
+        data
+            Various metadata set by subclasses
+            for internal use.
+        """
+        self._ansi: list[Any] = []
         self._off = [0]
         self._data = data
-        self._ground = _Ground.NONE
+        self._ground: _Ground = _Ground.NONE
     
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__}>"
     
     def __str__(self) -> str:
-        if self._ground == _Ground.NONE:
+        if not self.is_initialized:
             warnings.warn(
                 f"{self.__class__.__name__} instance at {hex(id(self))} is not initialized. "
                 "Use `.bg`, `.fg` or `.on()` to initialize it.",
@@ -113,15 +128,7 @@ class Color(Ansi, metaclass = ABCMeta):
         
         return self.enable_str()
     
-    def __add__(self, other: Ansi) -> Color:
-        """
-        Combines two styles.
-        
-        Raises
-        ------
-        ValueError
-            Colors cannot be combined.
-        """
+    def __add__(self, other: Ansi) -> Ansi:
         if isinstance(other, Color):
             _Ground.check((
                 operator.ne,
@@ -137,19 +144,9 @@ class Color(Ansi, metaclass = ABCMeta):
             return NotImplemented
         
         obj = copy(self)
-        obj.extend(other)
-        
-        return obj
+        return obj.extend(other)
     
-    def __iadd__(self, other: Ansi) -> Color:
-        """
-        Combines two styles.
-        
-        Raises
-        ------
-        ValueError
-            Colors cannot be combined.
-        """
+    def __iadd__(self, other: Ansi) -> Ansi:
         if isinstance(other, Color):
             _Ground.check((
                 operator.ne,
@@ -164,9 +161,7 @@ class Color(Ansi, metaclass = ABCMeta):
         elif not isinstance(other, Ansi):
             return NotImplemented
         
-        self.extend(other)
-        
-        return self
+        return self.extend(other)
     
     def __call__(self, *args: Any, **kwargs: Any) -> str:
         _Ground.check((
@@ -177,14 +172,31 @@ class Color(Ansi, metaclass = ABCMeta):
         
         return paint(*args, style = self, **kwargs)
     
-    def extend(self, *others: Ansi) -> Color:
+    def enable_str(self) -> str:
+        _Ground.check((
+            operator.ne,
+            self, _Ground.NONE,
+            NOT_INITIALIZED
+        ))
+        
+        return super().enable_str()
+    
+    def disable_str(self) -> str:
+        _Ground.check((
+            operator.ne,
+            self, _Ground.NONE,
+            NOT_INITIALIZED
+        ))
+        
+        return super().disable_str()
+    
+    def is_initialized(self) -> bool:
         """
-        Adds other ansi styles to this style.
+        .. versionadded:: 0.1.0
+        
+        Checks if the color is initialized or not.
         """
-        for other in others:
-            self._ansi.extend(other._ansi)
-            self._off.extend(other._off)
-        return self
+        return self._ground != _Ground.NONE
     
     def _get_ansi(self) -> str:
         return _get_ansi_string(self._ansi)
@@ -318,7 +330,10 @@ class Color(Ansi, metaclass = ABCMeta):
             hex = "".join(char * 2 for char in hex)
         
         elif len(hex) != 6:
-            raise ValueError(f"hex value must consist of 3 or 6 characters (e. g. `0xFFFFFF` or `0xFFF`")
+            raise ValueError(
+                f"hex value should consist of 3 or 6 characters "
+                "(e. g. `0xFFFFFF` or `0xFFF`)"
+            )
         
         h = iter(hex)
         
@@ -416,4 +431,11 @@ def from_name(*args: Any, **kwargs: Any) -> Color:
     col = get_color()
     return col.from_name(*args, **kwargs)
 
+def empty() -> Color0bit:
+    """
+    .. versionadded:: 0.1.0
+    
+    Returns a new instance of :class:`Color0bit`.
+    """
+    return Color0bit()
 
